<?php
if(!defined('PLX_ROOT')) { exit; }

/* A faire : s
 * Si le plugin est supprimé alors supprimer le fichier de données s'il existe
 * */

/**
 * kzEvents addon for PluXml
 *
 * Gestion évènementielle. Ajoute un champ date aux articles dans un fichier indépendant comme tags.xml.
 * Ajoute un tableau $aEvents à plxMotor
 * La date est sauvegardée au format "2024-09-22"
 * Incorporer le fichier sample.php au contenu d'une page statique
 * Compatible PHP 8.3.11 et PluXml 5.8.16
 *
 * @author Jean-Pierre Pourrez (aka bazooka07)
 * @date 2024-09-19
 * */
class kzEvents extends plxPlugin {
	const FIELDNAME = 'kzEvent';
	const DATAFILE = PLX_ROOT . PLX_CONFIG_PATH . 'plugins/' . __CLASS__.'-data.xml';
	const XML_HEADER = "<?xml version='1.0' encoding='" . PLX_CHARSET ."'?>" . PHP_EOL;
	const HOOKS = array(
		'plxMotorConstruct',
		'plxMotorParseArticle',
	);
	const ADMIN_HOOKS = array(
		'AdminArticlePreview',
		'AdminArticlePostData',
		'AdminArticleParseData',
		'AdminArticleInitData',
		'plxAdminEditArticleEnd',
		# 'plxAdminDelArticle',
		'AdminArticleSidebar',
	);
	const LANG = array(
		'de' => array(
			'ARTICLE_EVENT' => 'Veranstaltungsdatum',
		),
		'en' => array(
			'ARTICLE_EVENT' => 'Date of the event',
		),
		'es' => array(
			'ARTICLE_EVENT' => 'Fecha del evento',
		),
		'fr' => array(
			'ARTICLE_EVENT' => 'Date de l\'évènement',
		),
		'it' => array(
			'ARTICLE_EVENT' => 'Data dell\'evento',
		),
		'nl' => array(
			'ARTICLE_EVENT' => 'Datum evenement',
		),
		'oc' => array(
			'ARTICLE_EVENT' => 'date de l\'évènement',
		),
		'pl' => array(
			'ARTICLE_EVENT' => 'Data wydarzenia',
		),
		'pt' => array(
			'ARTICLE_EVENT' => 'Data do evento',
		),
		'ro' => array(
			'ARTICLE_EVENT' => 'Data evenimentului',
		),
		'ru' => array(
			'ARTICLE_EVENT' => 'Дата мероприятия',
		),
	);
	const BEGIN_CODE = '<?php # ' . __CLASS__ . ' plugin' . PHP_EOL;
	const END_CODE = PHP_EOL . '?>';

	public function __construct($lang) {
		parent::__construct($lang);

		foreach(self::HOOKS as $hook) {
			parent::addHook($hook, $hook);
		}

		if(defined('PLX_ADMIN')) {
			foreach(self::ADMIN_HOOKS as $hook) {
				parent::addHook($hook, $hook);
			}

			# Mimics plxPlugins::getPluginLang()
			$this->default_lang = $lang;
			$this->aLang = self::LANG[$lang];
		} else {
			# Hook à appeler depuis le site
			# parent::addHook('kzEvent', 'kzEvent');
		}
	}

	public function editEvents($datas) {
		# Génération du fichier XML
		if(empty($datas)) {
			if(file_exists(self::DATAFILE)) {
				unlink(self::DATAFILE);
			}
			return;
		}

		# on trie $datas selon la valeur pour la clé self::FIELDNAME
		uasort($datas, function($a, $b) {
			$result = strcmp($a[self::FIELDNAME], $b[self::FIELDNAME]);
			if($result != 0) {
				# tri sur dates d'évènements
				return $result;
			}

			# tri sur dates de publication
			return strcmp($a['date'], $b['date']);
		});
		ob_start();
?>
<document>
<?php
		foreach($datas as $art_id => $value) {
?>
	<article number="<?= $art_id ?>" date="<?= $value['date'] ?>" active="<?= $value['active'] ?>"><?= $value[self::FIELDNAME] ?></article>
<?php
		}
?>
</document>
<?php
		# On écrit le fichier
		plxUtils::write(self::XML_HEADER . ob_get_clean(), self::DATAFILE);
	}

	/* === Hooks === */

	public function plxMotorConstruct() {
		echo self::BEGIN_CODE;
		if(file_exists(self::DATAFILE)) {
?>
# like plxMotor::getTags()
$data = implode('',file('<?= self::DATAFILE ?>'));
$parser = xml_parser_create(PLX_CHARSET);
xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
xml_parse_into_struct($parser,$data,$values,$iTags);
xml_parser_free($parser);
$array = array();
# On verifie qu'il existe des tags "file"
if(isset($iTags['article'])) {
	# On compte le nombre de tags "file"
	$nb = sizeof($iTags['article']);
	# On boucle sur $nb
	for($i = 0; $i < $nb; $i++) {
		$item = $values[ $iTags['article'][$i] ];
		$array[ $item['attributes']['number'] ] = array(
			'<?= self::FIELDNAME ?>'  => isset($item['value']) ? trim($item['value']) : '',
			'date'   => $item['attributes']['date'],
			'active' => $item['attributes']['active'],
		);
	}
}
$this->aEvents = $array;
<?php
		} else {
?>
$this->aEvents = array();
<?php
		}
		echo self::END_CODE;
	}

	public function plxMotorParseArticle() {
		echo self::BEGIN_CODE;
?>
$art['<?= self::FIELDNAME ?>'] = array_key_exists($tmp['artId'], $this->aEvents) ? $this->aEvents[$tmp['artId']]['<?= self::FIELDNAME ?>'] : '';
<?php
		echo self::END_CODE;
	}

	/* === Hooks for back-office === */

	public function AdminArticlePreview() {
		echo self::BEGIN_CODE;
?>
$art['<?= self::FIELDNAME ?>'] = $_POST['<?= self::FIELDNAME ?>'];
<?php
		echo self::END_CODE;
	}

	public function AdminArticlePostData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = $_POST['<?= self::FIELDNAME ?>'];
<?php
		echo self::END_CODE;
	}

	public function AdminArticleParseData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = $result['<?= self::FIELDNAME ?>'];
<?php
		echo self::END_CODE;
	}

	public function AdminArticleInitData() {
		echo self::BEGIN_CODE;
?>
$kzEvent = '';
<?php
		echo self::END_CODE;
	}

	public function plxAdminEditArticleEnd() {
		echo self::BEGIN_CODE;
?>
$kzValue = trim($content['<?= self::FIELDNAME ?>']);
if(!empty($kzValue)) {
	$kzEventExtra = array(
		'<?= self::FIELDNAME ?>' => $kzValue,
		'date' => $time,
		'active' => intval(!in_array('draft', $content['catId'])),
	);

	if(array_key_exists($id, $this->aEvents) and empty(array_diff_assoc($kzEventExtra, $this->aEvents[$id]))) {
		# Aucun changement
		return;
	}

	# Mise à jour
	$this->aEvents[$id] = $kzEventExtra;
} elseif(array_key_exists($id, $this->aEvents)) {
	unset($this->aEvents[$id]);
} else {
	return;
}

# On sauvegarde les données
$this->plxPlugins->aPlugins['<?= __CLASS__ ?>']->editEvents($this->aEvents);
<?php
		echo self::END_CODE;
	}

	public function plxAdminDelArticle() {
		echo self::BEGIN_CODE;
?>
if($resDelArt AND $resDelCom and array_key_exists($id, $this->aEvents)) {
	unset($this->aEvents[$id]);
	# On sauvegarde les données
	$this->plxPlugins->aPlugins['<?= __CLASS__ ?>']->editEvents($this->aEvents);
}

# Process must continue for tags
return false;
<?php
		echo self::END_CODE;
	}

	public function AdminArticleSidebar() {
		$caption = $this->getLang('ARTICLE_EVENT');
?>
				<div class="grid">
					<div class="col sml-12">
						<label for="id_meta_keywords"><?= $caption ?>&nbsp;:</label>
<?php
		echo self::BEGIN_CODE;
?>
plxUtils::printInput('<?= self::FIELDNAME ?>', $kzEvent, 'date', '');
<?php
		echo self::END_CODE;
?>
					</div>
				</div>
<?php
	}

	/* === Hooks for thema === */

	public function kzEvent() {
		echo self::BEGIN_CODE;
?>
# $this is $plxShow
$plxMotor = plxMotor::getInstance();
$plxMotor->
$a = 3;
<?php
		echo self::END_CODE;
		return true;
	}

}
